<?php
/**
  _____________________________________________________________________________
 |
 |  Pix2Geo()
 |
 |  Postcondition:  This function converts the given pixel coordinate to a
 |                  geographic coordinate.
 |
 |  @param $nPixPos integer - Pixel position to convert.
 |  @param $dfPixMin double - Map min pixel value.
 |  @param $dfPixMax double - Map max pixel value.
 |  @param $dfGeoMin double - Map min extent.
 |  @param $dfGeoMax double - Map max extent.
 |  @param $bInversePix boolean - True if Y. 
 |
 |_____________________________________________________________________________
 
 **/
function Pix2Geo($nPixPos, $dfPixMin, $dfPixMax, $dfGeoMin, $dfGeoMax,
                 $bInversePix = false)
{
    $dfWidthGeo = $dfGeoMax - $dfGeoMin;
    $dfWidthPix = $dfPixMax - $dfPixMin;

    $dfPixToGeo = $dfWidthGeo / $dfWidthPix;

    if (!$bInversePix)
        $dfDeltaPix = $nPixPos - $dfPixMin;
    else
        $dfDeltaPix = $dfPixMax - $nPixPos;

    $dfDeltaGeo = $dfDeltaPix * $dfPixToGeo;


    $dfPosGeo = $dfGeoMin + $dfDeltaGeo;

    return ($dfPosGeo);
}

/**
  _____________________________________________________________________________
 |
 |  reportLayerStatus()
 |
 |  Postcondition:   This function generates the layer status report.
 |
 |  @param $oMap object - Map object to report on.
 |  @return string - report as a string.
 |  @desc Returns layer status report for given map.
 |_____________________________________________________________________________
 
 **/
function reportLayerStatus( &$oMap )
{
    // init vars
    $nOn = $nOff = $nDefault = 0;
    
    // loop thorugh the layers and count staus
    $nCount = $oMap->numlayers;
    for ( $i=0; $i<$nCount; $i++ )
    {
        // get next layer and check status
        $oLayer = $oMap->getlayer( $i );
        switch ( $oLayer->status )
        {
            case MS_ON:
                $nOn++;
                break;
            case MS_OFF:
                $nOff++;
                break;
            case MS_DEFAULT:
                $nDefault++;
                break;
        }
    }
    
    // return report
    return 'Layer Status:\nOn : '.$nOn.'\nOff : '.$nOff.'\n Default : '.
                                                                $nDefault;    
}

/**
  _____________________________________________________________________________
 |
 |  reportPixelCoords()
 |
 |  Postcondition:  This function returns a report for the given pixel coords.
 |
 |  @param $nPixX integer - X pixel position.
 |  @param $nPixY integer - Y pixel position.
 |  @return string - report.
 |  @desc Generates report for given pixel coords.
 |
 |_____________________________________________________________________________
 
 **/
function reportPixelCoords( $nPixX, $nPixY )
{
    return 'Pixel Coordinates:\n'.'X : '.$nPixX.'\n'.'Y : '.$nPixY.'\n';
}

/**
  _____________________________________________________________________________
 |
 |  reportGeoCoords()
 |
 |  Postcondition:  This function returns a report for the given pixel coords.
 |
 |  @param $nPixX integer - X pixel position.
 |  @param $nPixY integer - Y pixel position.
 |  @param $oMap object - map object to report on.
 |  @return string - report.
 |  @desc Generates report for given pixel coords.
 |
 |_____________________________________________________________________________
 
 **/
function reportGeoCoords( $nPixX, $nPixY, &$oMap )
{
    $szXGeo = Pix2Geo( $nPixX, 0, $oMap->width, $oMap->extent->minx, 
                                            $oMap->extent->maxx );
    $szYGeo = Pix2Geo( $nPixY, 0, $oMap->height, $oMap->extent->miny, 
                                      $oMap->extent->maxy, true );
    return 'Geographic Coordinates:\n'.'X : '.round( $szXGeo, 0 ).'\n'.
                                            'Y : '.round( $szYGeo, 0 ).'\n';
}

?>